@@ -14,6 +14,7 @@ from Cheese.resourceManager import ResMan
 from Cheese.appSettings import Settings
 from Cheese.ErrorCodes import Error
 from Cheese.metadata import Metadata
+from Cheese.adminFiles import AdminFiles
 
 class AdminManager:
 
@@ -23,7 +24,7 @@ class AdminManager:
             return
 
         if (server.path == "/admin"):
-            AdminManager.__sendFile(server, "/admin/index.html") 
+            AdminManager.__sendFile(server, "/admin/files/index.html") 
             return
         elif (server.path == "/admin/createUser"): #TODO
             AdminManager.__createUser(server)
@@ -79,14 +80,16 @@ class AdminManager:
 
     @staticmethod
     def __sendFile(server, file):
-        file = ResMan.joinPath(ResMan.admin(), *file.split("/")[2:])
-        if (not os.path.exists(file)):
+        file = file.replace("/", "_").replace(".", "_")
+        if (file[0] == "_"):
+            file = file[1:]
+            
+        if (not hasattr(AdminFiles, file)):
             with open(f"{ResMan.error()}/error404.html", "rb") as f:
                 CheeseController.sendResponse(server, (f.read(), 404))
             return
 
-        with open(f"{file}", "r", encoding="utf-8") as f:
-            CheeseController.sendResponse(server, (bytes(f.read(), "utf-8"), 200), "text/html")
+        CheeseController.sendResponse(server, (bytes(getattr(AdminFiles, file), "utf-8"), 200), "text/html")
 
     @staticmethod
     def __createUser(server):
